#!/bin/sh
# 
# Murus pf boot script for OS X 10.9-10.11 and macOS 10.12
#
# Murus is a pf GUI for macOS
# www.murusfirewall.com
# by The Murus Team
# info@murus.it
#
# This file is public domain.
#
#
# V 1.0.5 beta (Apr 2017)

# this beta script is a workaround to fix Murus logs bug on macOS 10.12.4
# here we simply make use of the old 'tcpdump' binary from macOS 10.12.3 to restore Murus logs functionalities.
 

#

#
# We need to trap on TERM signals, according to Apple's launchd docs:
#
trap 'exit 1' 15

#
# Use the "ipconfig waitall" command to wait for all the interfaces to come up:
#
ipconfig waitall
syslog -s -l 3 Murus: starting boot script
sleep 15
#
# System sysctl 
#
sysctl -w net.inet6.ip6.fw.verbose=0
sysctl -w net.inet.ip.fw.verbose=0
sysctl -w net.inet.ip.fw.verbose_limit=0

#
# interface forwarding enabled by default
#
sysctl -w net.inet.ip.forwarding=1
		
#		
# enable pf using tokens and load Murus rules
#
syslog -s -l 3 Murus: starting the pf packet filter...
/sbin/pfctl -f /etc/murus/murus.conf
/sbin/pfctl -E

#
# enable dummynet bandwidth shaping and load pipes and queues
#
syslog -s -l 3 Murus: loading dummynet rules...
if [ -f /usr/sbin/dnctl ];
then
# OS X 10.10,10.11, macOS 10.12
    /usr/sbin/dnctl /etc/murus/murus.dummynet
else
# OS X 10.9
    /sbin/ipfw /etc/murus/murus.dummynet
fi

#
# enable pf logs using tcpdump
#

# create virtual network interface for pf logging
syslog -s -l 3 Murus: creating pflog0 interface...
ifconfig pflog0 create

# get logs with tcpdump and pass output to system logger
syslog -s -l 3 Murus: starting pf logger...
osversion="$(uname -r | cut -d . -f 1)"
if [ "$osversion" = 16 ];
then
# macOS 10.12

# *** PLEASE NOTE ***
# /usr/local/bin/tcpdump must be manually installed.
# Here we need the binary exec from macOS 10.12.3 distribution
/usr/local/bin/tcpdump -lnettti pflog0 | /usr/local/bin/mlogger
else
# OS X 10.9, 10.10, 10.11
/usr/sbin/tcpdump -lnettti pflog0 | /usr/bin/logger -t pf -p local2.info
fi

# Exit with a clean status
exit 0

